@@ -1,6 +1,6 @@
 /* gdaui-entry-number.c
  *
- * Copyright (C) 2009 Vivien Malerba
+ * Copyright (C) 2009 - 2011 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -103,7 +103,8 @@ gdaui_entry_number_get_type (void)
 			NULL,
 			sizeof (GdauiEntryNumber),
 			0,
-			(GInstanceInitFunc) gdaui_entry_number_init
+			(GInstanceInitFunc) gdaui_entry_number_init,
+			0
 		};
 		
 		static const GInterfaceInfo cell_editable_info = {
@@ -141,15 +142,16 @@ gdaui_entry_number_class_init (GdauiEntryNumberClass * klass)
 	object_class->get_property = gdaui_entry_number_get_property;
 
 	g_object_class_install_property (object_class, PROP_EDITING_CANCELED,
-					 g_param_spec_boolean ("editing-canceled", NULL, NULL, FALSE, G_PARAM_READABLE));
+					 g_param_spec_boolean ("editing-canceled", NULL, NULL, FALSE,
+							       G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class, PROP_OPTIONS,
 					 g_param_spec_string ("options", NULL, NULL, NULL, G_PARAM_WRITABLE));
 }
 
 static gboolean
-key_press_event_cb (GdauiEntryNumber *mgstr, GdkEventKey *key_event, gpointer data)
+key_press_event_cb (GdauiEntryNumber *mgstr, GdkEventKey *key_event, G_GNUC_UNUSED gpointer data)
 {
-	if (key_event->keyval == GDK_Escape)
+	if (key_event->keyval == GDK_KEY_Escape)
 		mgstr->priv->editing_canceled = TRUE;
 	return FALSE;
 }
@@ -183,13 +185,13 @@ gdaui_entry_number_is_type_numeric (GType type)
 }
 
 /**
- * gdaui_entry_number_new
+ * gdaui_entry_number_new:
  * @dh: the data handler to be used by the new widget
  * @type: the requested data type (compatible with @dh)
  *
- * Creates a new widget which is mainly a GtkEntry
+ * Creates a new data entry widget
  *
- * Returns: the new widget
+ * Returns: (transfer full): the new widget
  */
 GtkWidget *
 gdaui_entry_number_new (GdaDataHandler *dh, GType type, const gchar *options)
@@ -254,9 +256,9 @@ gdaui_entry_number_finalize (GObject   * object)
 
 static void
 gdaui_entry_number_set_property (GObject *object,
-				    guint param_id,
-				    const GValue *value,
-				    GParamSpec *pspec)
+				 guint param_id,
+				 const GValue *value,
+				 GParamSpec *pspec)
 {
 	GdauiEntryNumber *mgstr;
 
@@ -266,6 +268,9 @@ gdaui_entry_number_set_property (GObject *object,
 		case PROP_OPTIONS:
 			set_entry_options (mgstr, g_value_get_string (value));
 			break;
+		case PROP_EDITING_CANCELED:
+			TO_IMPLEMENT;
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -275,9 +280,9 @@ gdaui_entry_number_set_property (GObject *object,
 
 static void
 gdaui_entry_number_get_property (GObject *object,
-			     guint param_id,
-			     GValue *value,
-			     GParamSpec *pspec)
+				 guint param_id,
+				 GValue *value,
+				 GParamSpec *pspec)
 {
 	GdauiEntryNumber *mgstr;
 
@@ -362,7 +367,7 @@ focus_out_cb (GtkWidget *widget, GdkEventFocus *event, GdauiEntryNumber *mgstr)
 	g_assert (activate_cb);
 	((Callback2)activate_cb) (widget, mgstr);
 
-	return FALSE;
+	return gtk_widget_event (GTK_WIDGET (mgstr), (GdkEvent*) event);
 }
 
 static void
@@ -384,7 +389,7 @@ connect_signals (GdauiEntryWrapper *mgwrap, GCallback modify_cb, GCallback activ
 }
 
 static gboolean
-can_expand (GdauiEntryWrapper *mgwrap, gboolean horiz)
+can_expand (G_GNUC_UNUSED GdauiEntryWrapper *mgwrap, G_GNUC_UNUSED gboolean horiz)
 {
 	return FALSE;
 }
@@ -415,13 +420,13 @@ grab_focus (GdauiEntryWrapper *mgwrap)
  * GtkCellEditable interface
  */
 static void
-gtk_cell_editable_entry_editing_done_cb (GtkEntry *entry, GdauiEntryNumber *mgstr) 
+gtk_cell_editable_entry_editing_done_cb (G_GNUC_UNUSED GtkEntry *entry, GdauiEntryNumber *mgstr)
 {
 	gtk_cell_editable_editing_done (GTK_CELL_EDITABLE (mgstr));
 }
 
 static void
-gtk_cell_editable_entry_remove_widget_cb (GtkEntry *entry, GdauiEntryNumber *mgstr) 
+gtk_cell_editable_entry_remove_widget_cb (G_GNUC_UNUSED GtkEntry *entry, GdauiEntryNumber *mgstr)
 {
 	gtk_cell_editable_remove_widget (GTK_CELL_EDITABLE (mgstr));
 }
