@@ -1,6 +1,6 @@
 /* gdaui-basic-form.c
  *
- * Copyright (C) 2002 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2002 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -91,6 +91,8 @@ typedef struct {
 	}               pack;
 	
 } SingleEntry;
+static void real_gdaui_basic_form_entry_set_visible (GdauiBasicForm *form,
+						      SingleEntry *sentry, gboolean show);
 static SingleEntry *get_single_entry_for_holder (GdauiBasicForm *form, GdaHolder *param);
 static SingleEntry *get_single_entry_for_id (GdauiBasicForm *form, const gchar *id);
 static void create_entry_widget (SingleEntry *sentry);
@@ -122,6 +124,7 @@ enum {
 	HOLDER_CHANGED,
 	ACTIVATED,
 	LAYOUT_CHANGED,
+	POPULATE_POPUP,
 	LAST_SIGNAL
 };
 
@@ -149,18 +152,20 @@ size_group_free (SizeGroup *sg)
 
 struct _GdauiBasicFormPriv
 {
-	GdaSet                 *set;
-	GdauiSet               *set_info;
-	GSList                 *s_entries;/* list of SingleEntry pointers */
-	GHashTable             *place_holders; /* key = place holder ID, value = a GtkWidget pointer */
+	GdaSet     *set;
+	GdauiSet   *set_info;
+	GSList     *s_entries;/* list of SingleEntry pointers */
+	GHashTable *place_holders; /* key = place holder ID, value = a GtkWidget pointer */
 
-	GtkWidget              *top_container;
+	GtkWidget  *top_container;
 
-	gboolean                headers_sensitive;
-	gboolean                show_actions;
-	gboolean                entries_auto_default;
+	gboolean    headers_sensitive;
+	gboolean    show_actions;
+	gboolean    entries_auto_default;
 
-	GSList                 *size_groups; /* list of SizeGroup pointers */
+	GSList     *size_groups; /* list of SizeGroup pointers */
+
+	GtkWidget  *mainbox;
 };
 
 
@@ -184,7 +189,8 @@ gdaui_basic_form_get_type (void)
 			NULL,
 			sizeof (GdauiBasicForm),
 			0,
-			(GInstanceInitFunc) gdaui_basic_form_init
+			(GInstanceInitFunc) gdaui_basic_form_init,
+			0
 		};
 
 		type = g_type_register_static (GTK_TYPE_VBOX, "GdauiBasicForm", &info, 0);
@@ -203,11 +209,11 @@ gdaui_basic_form_class_init (GdauiBasicFormClass * class)
 	/* signals */
 	/**
 	 * GdauiBasicForm::holder-changed:
-	 * @form: GdauiBasicForm
-	 * @param: that changed
+	 * @form: #GdauiBasicForm
+	 * @param: the #GdaHolder that changed
 	 * @is_user_modif: TRUE if the modification has been initiated by a user modification
 	 *
-	 * Emitted when a GdaHolder changes
+	 * Emitted when a GdaHolder changed in @form
 	 */
 	gdaui_basic_form_signals[HOLDER_CHANGED] =
 		g_signal_new ("holder-changed",
@@ -219,7 +225,7 @@ gdaui_basic_form_class_init (GdauiBasicFormClass * class)
 			      GDA_TYPE_HOLDER, G_TYPE_BOOLEAN);
 	/**
 	 * GdauiBasicForm::activated:
-	 * @form: GdauiBasicForm
+	 * @form: #GdauiBasicForm
 	 *
 	 * Emitted when the use has activated any of the #GdaDataEntry widget
 	 * in @form.
@@ -234,7 +240,7 @@ gdaui_basic_form_class_init (GdauiBasicFormClass * class)
 
 	/**
 	 * GdauiBasicForm::layout-changed:
-	 * @form: GdauiBasicForm
+	 * @form: #GdauiBasicForm
 	 *
 	 * Emitted when the form's layout changes
 	 */
@@ -246,6 +252,24 @@ gdaui_basic_form_class_init (GdauiBasicFormClass * class)
 			      NULL, NULL,
 			      _gdaui_marshal_VOID__VOID, G_TYPE_NONE, 0);
 
+	/**
+	 * GdauiBasicForm::populate-popup:
+	 * @form: #GdauiBasicForm
+	 * @menu: a #GtkMenu to modify
+	 *
+	 * Connect this signal and modify the popup menu.
+	 *
+	 * Since: 4.2.4
+	 */
+	gdaui_basic_form_signals[POPULATE_POPUP] =
+		g_signal_new ("populate-popup",
+                              G_TYPE_FROM_CLASS (object_class),
+                              G_SIGNAL_RUN_FIRST,
+                              0,
+                              NULL, NULL,
+                              _gdaui_marshal_VOID__OBJECT, G_TYPE_NONE,
+			      1, GTK_TYPE_MENU);
+
 	class->holder_changed = NULL;
 	class->activated = NULL;
 	class->layout_changed = NULL;
@@ -287,8 +311,81 @@ gdaui_basic_form_class_init (GdauiBasicFormClass * class)
 }
 
 static void
-gdaui_basic_form_init (GdauiBasicForm * wid)
+hidden_entry_mitem_toggled_cb (GtkCheckMenuItem *check, GdauiBasicForm *form)
 {
+	SingleEntry *sentry;
+	sentry = g_object_get_data (G_OBJECT (check), "s");
+	g_assert (sentry);
+	real_gdaui_basic_form_entry_set_visible (form, sentry,
+						 gtk_check_menu_item_get_active (check));
+}
+
+static void
+do_popup_menu (GdauiBasicForm *form, GdkEventButton *event)
+{
+	int button, event_time;
+	GtkWidget *menu, *submenu, *mitem;
+	GSList *list;
+	
+	menu = gtk_menu_new ();
+	mitem = gtk_menu_item_new_with_label (_("Shown data entries"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), mitem);
+	gtk_widget_show (mitem);
+	
+	submenu = gtk_menu_new ();
+	gtk_widget_show (submenu);
+	gtk_menu_item_set_submenu (GTK_MENU_ITEM (mitem), submenu);
+	
+	for (list = form->priv->s_entries; list; list = list->next) {
+		SingleEntry *sentry = (SingleEntry*) list->data;
+		mitem = gtk_check_menu_item_new_with_label (sentry->label_title);
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mitem), !sentry->hidden);
+		gtk_menu_shell_append (GTK_MENU_SHELL (submenu), mitem);
+		gtk_widget_show (mitem);
+
+		g_object_set_data (G_OBJECT (mitem), "s", sentry);
+		g_signal_connect (mitem, "toggled",
+				  G_CALLBACK (hidden_entry_mitem_toggled_cb), form);
+	}
+		
+	if (event) {
+		button = event->button;
+		event_time = event->time;
+	}
+	else {
+		button = 0;
+		event_time = gtk_get_current_event_time ();
+	}
+
+	/* allow listeners to add their custom menu items */
+	g_signal_emit (G_OBJECT (form), gdaui_basic_form_signals [POPULATE_POPUP], 0, GTK_MENU (menu));
+
+	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 
+			button, event_time);
+}
+
+static gboolean
+popup_menu_cb (G_GNUC_UNUSED GtkWidget *wid, GdauiBasicForm *form)
+{
+	do_popup_menu (form, NULL);
+	return TRUE;
+}
+
+static gboolean
+button_press_event_cb (G_GNUC_UNUSED GdauiBasicForm *wid, GdkEventButton *event, GdauiBasicForm *form)
+{
+	if (event->button == 3 && event->type == GDK_BUTTON_PRESS) {
+		do_popup_menu (form, event);
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+static void
+gdaui_basic_form_init (GdauiBasicForm *wid)
+{
+	GtkWidget *evbox;
 	wid->priv = g_new0 (GdauiBasicFormPriv, 1);
 	wid->priv->set = NULL;
 	wid->priv->s_entries = NULL;
@@ -298,6 +395,18 @@ gdaui_basic_form_init (GdauiBasicForm * wid)
 	wid->priv->headers_sensitive = FALSE;
 	wid->priv->show_actions = FALSE;
 	wid->priv->entries_auto_default = FALSE;
+
+	evbox = gtk_event_box_new ();
+	gtk_widget_show (evbox);
+	gtk_box_pack_start (GTK_BOX (wid), evbox, TRUE, TRUE, 0);
+	wid->priv->mainbox = gtk_vbox_new (FALSE, 0);
+	gtk_widget_show (wid->priv->mainbox);
+	gtk_container_add (GTK_CONTAINER (evbox), wid->priv->mainbox);
+
+	g_signal_connect (evbox, "popup-menu",
+			  G_CALLBACK (popup_menu_cb), wid);
+	g_signal_connect (evbox, "button-press-event",
+			  G_CALLBACK (button_press_event_cb), wid);
 }
 
 /**
@@ -370,7 +479,7 @@ get_rid_of_set (GdaSet *paramlist, GdauiBasicForm *form)
 }
 
 static void
-paramlist_holder_type_set_cb (GdaSet *paramlist, GdaHolder *param,
+paramlist_holder_type_set_cb (G_GNUC_UNUSED GdaSet *paramlist, GdaHolder *param,
 			      GdauiBasicForm *form)
 {
 	SingleEntry *sentry;
@@ -388,7 +497,7 @@ paramlist_holder_type_set_cb (GdaSet *paramlist, GdaHolder *param,
 
 
 static void
-paramlist_public_data_changed_cb (GdauiSet *paramlist, GdauiBasicForm *form)
+paramlist_public_data_changed_cb (G_GNUC_UNUSED GdauiSet *paramlist, GdauiBasicForm *form)
 {
 	/* here we want to re-define all the data entry widgets */
 	destroy_entries (form);
@@ -398,8 +507,9 @@ paramlist_public_data_changed_cb (GdauiSet *paramlist, GdauiBasicForm *form)
 }
 
 static void
-paramlist_param_attr_changed_cb (GdaSet *paramlist, GdaHolder *param,
-				 const gchar *att_name, const GValue *att_value, GdauiBasicForm *form)
+paramlist_param_attr_changed_cb (G_GNUC_UNUSED GdaSet *paramlist, GdaHolder *param,
+				 const gchar *att_name, G_GNUC_UNUSED const GValue *att_value,
+				 GdauiBasicForm *form)
 {
 	SingleEntry *sentry;
 
@@ -638,7 +748,7 @@ disconnect_single_entry_signals (SingleEntry *sentry)
 		sd->holder = NULL;
 	}
 	if (sentry->group_signals) {
-		gint i;
+		gsize i;
 		for (i = 0; i < sentry->group_signals->len; i++) {
 			SignalData sd = g_array_index (sentry->group_signals, SignalData,
 						       i);
@@ -725,7 +835,6 @@ create_text_label_for_sentry (SingleEntry *sentry, gchar **out_title)
 
 	}
 	else {
-		gchar *label;
 		GSList *params;
 		gchar *title = NULL;
 
@@ -1069,7 +1178,7 @@ pack_entries_in_table (GdauiBasicForm *form)
 	gtk_table_set_row_spacings (GTK_TABLE (table), SPACING);
 	gtk_table_set_col_spacings (GTK_TABLE (table), SPACING);
 	form->priv->top_container = table;
-	gtk_box_pack_start (GTK_BOX (form), table, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (form->priv->mainbox), table, TRUE, TRUE, 0);
 	for (list = form->priv->s_entries, i = 0;
 	     list;
 	     list = list->next, i++) {
@@ -1105,7 +1214,7 @@ pack_entries_in_xml_layout (GdauiBasicForm *form, xmlNodePtr form_node)
 	}
 
 	top = load_xml_layout_children (form, form_node);
-	gtk_box_pack_start (GTK_BOX (form), top, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (form->priv->mainbox), top, TRUE, TRUE, 0);
 	gtk_widget_show_all (top);
 	mark_not_null_entry_labels (form, TRUE);
 }
@@ -1340,7 +1449,7 @@ mark_not_null_entry_labels (GdauiBasicForm *form, gboolean show_mark)
 }
 
 static void
-entry_contents_activated (GdauiDataEntry *entry, GdauiBasicForm *form)
+entry_contents_activated (G_GNUC_UNUSED GdauiDataEntry *entry, GdauiBasicForm *form)
 {
 	g_signal_emit (G_OBJECT (form), gdaui_basic_form_signals[ACTIVATED], 0);
 }
@@ -1447,7 +1556,7 @@ entry_contents_modified (GdauiDataEntry *entry, SingleEntry *sentry)
 }
 
 static void
-entry_expand_changed_cb (GdauiDataEntry *entry, SingleEntry *sentry)
+entry_expand_changed_cb (G_GNUC_UNUSED GdauiDataEntry *entry, SingleEntry *sentry)
 {
 	pack_entry_widget (sentry);
 }
@@ -1713,31 +1822,11 @@ gdaui_basic_form_reset (GdauiBasicForm *form)
 	}
 }
 
-
-/**
- * gdaui_basic_form_entry_set_visible:
- * @form: a #GdauiBasicForm widget
- * @param: a #GdaHolder object
- * @show: set to %TRUE to show the data entry, and to %FALSE to hide it
- *
- * Shows or hides the #GdauiDataEntry in @form which corresponds to the
- * @param parameter
- *
- * Since: 4.2
- */
-void
-gdaui_basic_form_entry_set_visible (GdauiBasicForm *form, GdaHolder *param, gboolean show)
+static void
+real_gdaui_basic_form_entry_set_visible (GdauiBasicForm *form, SingleEntry *sentry, gboolean show)
 {
-	SingleEntry *sentry;
-
 	g_return_if_fail (GDAUI_IS_BASIC_FORM (form));
-	g_return_if_fail (GDA_IS_HOLDER (param));
-
-	sentry = get_single_entry_for_holder (form, param);
-	if (!sentry) {
-		g_warning (_("Can't find data entry for GdaHolder"));
-		return;
-	}
+	g_return_if_fail (sentry);
 
 	if (sentry->entry) {
 		if (show) {
@@ -1777,6 +1866,34 @@ gdaui_basic_form_entry_set_visible (GdauiBasicForm *form, GdaHolder *param, gboo
 	}
 }
 
+/**
+ * gdaui_basic_form_entry_set_visible:
+ * @form: a #GdauiBasicForm widget
+ * @param: a #GdaHolder object
+ * @show: set to %TRUE to show the data entry, and to %FALSE to hide it
+ *
+ * Shows or hides the #GdauiDataEntry in @form which corresponds to the
+ * @param parameter
+ *
+ * Since: 4.2
+ */
+void
+gdaui_basic_form_entry_set_visible (GdauiBasicForm *form, GdaHolder *param, gboolean show)
+{
+	SingleEntry *sentry;
+
+	g_return_if_fail (GDAUI_IS_BASIC_FORM (form));
+	g_return_if_fail (GDA_IS_HOLDER (param));
+
+	sentry = get_single_entry_for_holder (form, param);
+	if (!sentry) {
+		g_warning (_("Can't find data entry for GdaHolder"));
+		return;
+	}
+
+	real_gdaui_basic_form_entry_set_visible (form, sentry, show);
+}
+
 /**
  * gdaui_basic_form_entry_grab_focus:
  * @form: a #GdauiBasicForm widget
@@ -2016,6 +2133,7 @@ gdaui_basic_form_new_in_dialog (GdaSet *data_set, GtkWindow *parent,
 					   GTK_STOCK_OK,
 					   GTK_RESPONSE_ACCEPT,
 					   NULL);
+	gtk_dialog_set_default_response (GTK_DIALOG (dlg), GTK_RESPONSE_ACCEPT);
 	if (header && *header) {
 		GtkWidget *label;
 		gchar *str;
@@ -2025,27 +2143,17 @@ gdaui_basic_form_new_in_dialog (GdaSet *data_set, GtkWindow *parent,
 		str = g_markup_printf_escaped ("<b>%s:</b>", header);
 		gtk_label_set_markup (GTK_LABEL (label), str);
 		g_free (str);
-#if GTK_CHECK_VERSION(2,18,0)
 		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
 				    label, FALSE, FALSE, SPACING);
-#else
-		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), label, FALSE, FALSE, SPACING);
-#endif
 		gtk_widget_show (label);
 	}
 
 
 	gboolean can_expand;
 	g_object_get ((GObject*) form, "can-expand-v", &can_expand, NULL);
-#if GTK_CHECK_VERSION(2,18,0)
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg)))), 4);
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))), form,
 			    can_expand, can_expand, 10);
-#else
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dlg)->vbox), 4);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), form,
-			    can_expand, can_expand, 10);
-#endif
 
 	g_signal_connect (G_OBJECT (form), "holder-changed",
 			  G_CALLBACK (form_holder_changed), dlg);
@@ -2058,7 +2166,8 @@ gdaui_basic_form_new_in_dialog (GdaSet *data_set, GtkWindow *parent,
 }
 
 static void
-form_holder_changed (GdauiBasicForm *form, GdaHolder *param, gboolean is_user_modif, GtkDialog *dlg)
+form_holder_changed (GdauiBasicForm *form, G_GNUC_UNUSED GdaHolder *param,
+		     G_GNUC_UNUSED gboolean is_user_modif, GtkDialog *dlg)
 {
 	gboolean valid;
 
