@@ -129,7 +129,7 @@ gdaui_login_class_init (GdauiLoginClass *klass)
 }
 
 static void
-config_dsn_changed_cb (GdaConfig *config, GdaDsnInfo *dsn, GdauiLogin *login)
+config_dsn_changed_cb (G_GNUC_UNUSED GdaConfig *config, GdaDsnInfo *dsn, GdauiLogin *login)
 {
 	if (!login->priv->prov_selector)
 		return;
@@ -142,7 +142,7 @@ config_dsn_changed_cb (GdaConfig *config, GdaDsnInfo *dsn, GdauiLogin *login)
 }
 
 static void
-gdaui_login_init (GdauiLogin *login, GdauiLoginClass *klass)
+gdaui_login_init (GdauiLogin *login, G_GNUC_UNUSED GdauiLoginClass *klass)
 {
 	GtkWidget *table;
 	GtkWidget *wid;
@@ -155,8 +155,10 @@ gdaui_login_init (GdauiLogin *login, GdauiLoginClass *klass)
 	memset (&(login->priv->dsn_info), 0, sizeof (GdaDsnInfo));
 	
 	/* catch DSN definition changes */
-	g_signal_connect (gda_config_get (), "dsn-changed",
+	GdaConfig *conf = gda_config_get ();
+	g_signal_connect (conf, "dsn-changed",
 			  G_CALLBACK (config_dsn_changed_cb), login);
+	g_object_unref (conf);
 
 	/* table layout */
 	table = gtk_table_new (3, 3, FALSE);
@@ -298,8 +300,10 @@ gdaui_login_finalize (GObject *object)
 
 	g_return_if_fail (GDAUI_IS_LOGIN (login));
 
-	g_signal_handlers_disconnect_by_func (gda_config_get (),
+	GdaConfig *conf = gda_config_get ();
+	g_signal_handlers_disconnect_by_func (conf,
 					      G_CALLBACK (config_dsn_changed_cb), login);
+	g_object_unref (conf);
 
 	/* free memory */
 	clear_dsn_info (login);
@@ -324,7 +328,8 @@ gdaui_login_get_type (void)
 			NULL,
 			sizeof (GdauiLogin),
 			0,
-			(GInstanceInitFunc) gdaui_login_init
+			(GInstanceInitFunc) gdaui_login_init,
+			0
 		};
 		type = g_type_register_static (GTK_TYPE_VBOX, "GdauiLogin", &info, 0);
 	}
@@ -377,42 +382,47 @@ radio_button_use_dsn_toggled_cb (GtkToggleButton *button, GdauiLogin *login)
 }
 
 static void
-run_cc_cb (GtkButton *button, GdauiLogin *login)
+run_cc_cb (G_GNUC_UNUSED GtkButton *button, GdauiLogin *login)
 {
-	char *argv[2];
+	GAppInfo *appinfo;
+	GdkAppLaunchContext *context;
+	GdkScreen *screen;
 	gboolean sresult;
 	GError *lerror = NULL;
+	gchar *cmd;
 	
 #ifdef G_OS_WIN32
 #define EXENAME "gda-control-center-" GDA_ABI_VERSION ".exe"
 #else
 #define EXENAME "gda-control-center-" GDA_ABI_VERSION
 #endif
-	/* run gnome-database-properties dictig tool */
-	argv[0] = gda_gbr_get_file_path (GDA_BIN_DIR, (char *) EXENAME, NULL);
-	argv[1] = NULL;
-        
-	sresult = gdk_spawn_on_screen (gtk_widget_get_screen (GTK_WIDGET (login)),
-				       NULL, argv, NULL, 0,
-				       NULL, NULL, NULL, &lerror);
-	if (!sresult && lerror && (lerror->domain == G_SPAWN_ERROR) && (lerror->code == G_SPAWN_ERROR_NOENT)) {
-		g_error_free (lerror);
-		lerror = NULL;
-		g_free (argv [0]);
-		argv[0] = g_strdup ((char *) EXENAME);
-		sresult = gdk_spawn_on_screen (gtk_widget_get_screen (GTK_WIDGET (login)),
-					       NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
-					       NULL, NULL, NULL, &lerror);
+	/* run gnome-database-properties tool */
+	cmd = gda_gbr_get_file_path (GDA_BIN_DIR, (char *) EXENAME, NULL);
+	appinfo = g_app_info_create_from_commandline (cmd,
+						      "Gda Control center",
+						      G_APP_INFO_CREATE_NONE,
+						      NULL);
+	g_free (cmd);
+
+	screen = gtk_widget_get_screen (GTK_WIDGET (login));
+	context = gdk_display_get_app_launch_context (gdk_screen_get_display (screen));
+	gdk_app_launch_context_set_screen (context, screen);
+	sresult = g_app_info_launch (appinfo, NULL, G_APP_LAUNCH_CONTEXT (context), NULL);
+	if (! sresult) {
+		g_object_unref (appinfo);
+		appinfo = g_app_info_create_from_commandline (EXENAME,
+							      "Gda Control center",
+							      G_APP_INFO_CREATE_NONE,
+							      NULL);
+		sresult = g_app_info_launch (appinfo, NULL, G_APP_LAUNCH_CONTEXT (context), &lerror);
 	}
-	g_free (argv [0]);
+	g_object_unref (context);
+	g_object_unref (appinfo);
+
 	if (!sresult) {
 		GtkWidget *msgdialog;
 		GtkWidget *toplevel = gtk_widget_get_toplevel (GTK_WIDGET (login));
-#if GTK_CHECK_VERSION(2,18,0)
 		if (!gtk_widget_is_toplevel (toplevel))
-#else
-		if (!GTK_WIDGET_TOPLEVEL (toplevel))
-#endif
 			toplevel = NULL;
 		msgdialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (toplevel), GTK_DIALOG_MODAL,
 								GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
@@ -480,7 +490,7 @@ prov_entry_changed_cb (GdauiProviderSelector *sel, GdauiLogin *login)
 }
 
 static void
-cnc_params_editor_changed_cb (GdauiProviderSpecEditor *editor, GdauiLogin *login)
+cnc_params_editor_changed_cb (G_GNUC_UNUSED GdauiProviderSpecEditor *editor, GdauiLogin *login)
 {
 	g_signal_emit (login, gdaui_login_signals [CHANGED], 0, settings_are_valid (login));
 }
@@ -496,7 +506,7 @@ cnc_params_editor_changed_cb (GdauiProviderSpecEditor *editor, GdauiLogin *login
  * Since: 4.2
 */
 GtkWidget *
-gdaui_login_new (const gchar *dsn)
+gdaui_login_new (G_GNUC_UNUSED const gchar *dsn)
 {
 	GtkWidget *login;
 
