@@ -31,7 +31,7 @@
 #include "../cc-gray-bar.h"
 #include "marshal.h"
 #include <gdk/gdkkeysyms.h>
-#include "popup-container.h"
+#include <libgda-ui/internal/popup-container.h>
 
 struct _ObjectsCloudPrivate {
 	gboolean             show_schemas;
@@ -84,7 +84,7 @@ objects_cloud_class_init (ObjectsCloudClass *klass)
 
 
 static void
-objects_cloud_init (ObjectsCloud *cloud, ObjectsCloudClass *klass)
+objects_cloud_init (ObjectsCloud *cloud, G_GNUC_UNUSED ObjectsCloudClass *klass)
 {
 	cloud->priv = g_new0 (ObjectsCloudPrivate, 1);
 	cloud->priv->show_schemas = FALSE;
@@ -126,7 +126,8 @@ objects_cloud_get_type (void)
 			NULL,
 			sizeof (ObjectsCloud),
 			0,
-			(GInstanceInitFunc) objects_cloud_init
+			(GInstanceInitFunc) objects_cloud_init,
+			0
 		};
 		type = g_type_register_static (GTK_TYPE_VBOX, "ObjectsCloud",
 					       &info, 0);
@@ -522,15 +523,11 @@ set_cursor_if_appropriate (GtkTextView *text_view, gint x, gint y, ObjectsCloud
  * (e.g. when a window covering it got iconified).
  */
 static gboolean
-visibility_notify_event (GtkWidget *text_view, GdkEventVisibility *event, ObjectsCloud *cloud)
+visibility_notify_event (GtkWidget *text_view, G_GNUC_UNUSED GdkEventVisibility *event, ObjectsCloud *cloud)
 {
 	gint wx, wy, bx, by;
 
-#if GTK_CHECK_VERSION(2,18,0)
 	gdk_window_get_pointer (gtk_widget_get_window (text_view), &wx, &wy, NULL);
-#else
-	gdk_window_get_pointer (text_view->window, &wx, &wy, NULL);
-#endif
 	
 	gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (text_view), 
 					       GTK_TEXT_WINDOW_WIDGET,
@@ -554,11 +551,7 @@ motion_notify_event (GtkWidget *text_view, GdkEventMotion *event, ObjectsCloud *
 					       event->x, event->y, &x, &y);
 	
 	set_cursor_if_appropriate (GTK_TEXT_VIEW (text_view), x, y, cloud);
-#if GTK_CHECK_VERSION(2,18,0)
 	gdk_window_get_pointer (gtk_widget_get_window (text_view), NULL, NULL, NULL);
-#else
-	gdk_window_get_pointer (text_view->window, NULL, NULL, NULL);
-#endif
 	return FALSE;
 }
 
@@ -568,7 +561,7 @@ motion_notify_event (GtkWidget *text_view, GdkEventMotion *event, ObjectsCloud *
  * by the data attached to it.
  */
 static void
-follow_if_link (GtkWidget *text_view, GtkTextIter *iter, ObjectsCloud *cloud)
+follow_if_link (G_GNUC_UNUSED GtkWidget *text_view, GtkTextIter *iter, ObjectsCloud *cloud)
 {
 	GSList *tags = NULL, *tagp = NULL;
 	
@@ -652,8 +645,8 @@ key_press_event (GtkWidget *text_view, GdkEventKey *event, ObjectsCloud *cloud)
 	GtkTextBuffer *buffer;
 	
 	switch (event->keyval) {
-	case GDK_Return: 
-	case GDK_KP_Enter:
+	case GDK_KEY_Return: 
+	case GDK_KEY_KP_Enter:
 		buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
 		gtk_text_buffer_get_iter_at_mark (buffer, &iter, 
 						  gtk_text_buffer_get_insert (buffer));
